@@ -1,20 +1,19 @@
 from shrub.v3.evg_build_variant import BuildVariant
 from shrub.v3.evg_command import EvgCommandType, FunctionCall, expansions_update
-from shrub.v3.evg_task import EvgTask, EvgTaskRef, EvgTaskDependency
+from shrub.v3.evg_task import EvgTask, EvgTaskDependency, EvgTaskRef
 
 from config_generator.components.funcs.bootstrap_mongo_orchestration import BootstrapMongoOrchestration
 from config_generator.components.funcs.fetch_build import FetchBuild
 from config_generator.components.funcs.fetch_det import FetchDET
-from config_generator.components.funcs.find_cmake_latest import FindCMakeLatest
 from config_generator.components.funcs.run_simple_http_server import RunSimpleHTTPServer
 from config_generator.components.funcs.run_tests import RunTests
 from config_generator.components.funcs.upload_build import UploadBuild
-from config_generator.etc.distros import make_distro_str, find_small_distro, find_large_distro
+from config_generator.etc.distros import find_large_distro, make_distro_str
 from config_generator.etc.utils import bash_exec
 
 # Use `rhel8-latest` distro. `rhel8-latest` distro includes necessary dependency: `haproxy`.
-_DISTRO_NAME = "rhel8-latest"
-_COMPILER = "gcc"
+_DISTRO_NAME = 'rhel8-latest'
+_COMPILER = 'gcc'
 
 
 def functions():
@@ -22,50 +21,52 @@ def functions():
         'start-load-balancer': [
             bash_exec(
                 command_type=EvgCommandType.SETUP,
-                script='''\
+                script="""\
                     export DRIVERS_TOOLS=./drivers-evergreen-tools
                     export MONGODB_URI="${MONGODB_URI}"
+                    export PATH="$(uv tool dir --bin):$PATH" # DEVPROD-19733
                     $DRIVERS_TOOLS/.evergreen/run-load-balancer.sh start
-                ''',
+                """,
             ),
             expansions_update(
                 command_type=EvgCommandType.SETUP,
                 file='lb-expansion.yml',
-            )
+            ),
         ]
     }
 
 
 def make_test_task(auth: bool, ssl: bool, server_version: str):
-    auth_str = "auth" if auth else "noauth"
-    ssl_str = "openssl" if ssl else "nossl"
+    auth_str = 'auth' if auth else 'noauth'
+    ssl_str = 'openssl' if ssl else 'nossl'
     distro_str = make_distro_str(_DISTRO_NAME, _COMPILER, None)
     return EvgTask(
-        name=f"loadbalanced-{distro_str}-test-{server_version}-{auth_str}-{ssl_str}",
-        depends_on=[EvgTaskDependency(
-            name=f"loadbalanced-{distro_str}-compile")],
-        run_on=find_large_distro(_DISTRO_NAME).name, # DEVPROD-18763
+        name=f'loadbalanced-{distro_str}-test-{server_version}-{auth_str}-{ssl_str}',
+        depends_on=[EvgTaskDependency(name=f'loadbalanced-{distro_str}-compile')],
+        run_on=find_large_distro(_DISTRO_NAME).name,  # DEVPROD-18763
         tags=['loadbalanced', _DISTRO_NAME, _COMPILER, auth_str, ssl_str],
         commands=[
-            FetchBuild.call(build_name=f"loadbalanced-{distro_str}-compile"),
+            FetchBuild.call(build_name=f'loadbalanced-{distro_str}-compile'),
             FetchDET.call(),
-            BootstrapMongoOrchestration().call(vars={
-                'AUTH': auth_str,
-                'SSL': ssl_str,
-                'MONGODB_VERSION': server_version,
-                'TOPOLOGY': 'sharded_cluster',
-                'LOAD_BALANCER': 'on',
-            }),
+            BootstrapMongoOrchestration().call(
+                vars={
+                    'AUTH': auth_str,
+                    'SSL': ssl_str,
+                    'MONGODB_VERSION': server_version,
+                    'TOPOLOGY': 'sharded_cluster',
+                    'LOAD_BALANCER': 'on',
+                }
+            ),
             RunSimpleHTTPServer.call(),
-            FunctionCall(func='start-load-balancer', vars={
-                'MONGODB_URI': 'mongodb://localhost:27017,localhost:27018'
-            }),
-            RunTests().call(vars={
-                'AUTH': auth_str,
-                'SSL': ssl_str,
-                'LOADBALANCED': 'loadbalanced',
-                'CC': _COMPILER,
-            })
+            FunctionCall(func='start-load-balancer', vars={'MONGODB_URI': 'mongodb://localhost:27017,localhost:27018'}),
+            RunTests().call(
+                vars={
+                    'AUTH': auth_str,
+                    'SSL': ssl_str,
+                    'LOADBALANCED': 'loadbalanced',
+                    'CC': _COMPILER,
+                }
+            ),
         ],
     )
 
@@ -73,22 +74,18 @@ def make_test_task(auth: bool, ssl: bool, server_version: str):
 def tasks():
     distro_str = make_distro_str(_DISTRO_NAME, _COMPILER, None)
     yield EvgTask(
-        name=f"loadbalanced-{distro_str}-compile",
+        name=f'loadbalanced-{distro_str}-compile',
         run_on=find_large_distro(_DISTRO_NAME).name,
         tags=['loadbalanced', _DISTRO_NAME, _COMPILER],
         commands=[
-            FindCMakeLatest.call(),
             bash_exec(
                 command_type=EvgCommandType.TEST,
-                env={
-                    'CC': _COMPILER,
-                    'CFLAGS': '-fno-omit-frame-pointer',
-                    'SSL': 'OPENSSL'
-                },
+                env={'CC': _COMPILER, 'CFLAGS': '-fno-omit-frame-pointer', 'SSL': 'OPENSSL'},
+                include_expansions_in_env=['distro_id'],
                 working_dir='mongoc',
                 script='.evergreen/scripts/compile.sh',
             ),
-            UploadBuild.call()
+            UploadBuild.call(),
         ],
     )
 
@@ -107,9 +104,5 @@ def tasks():
 
 def variants():
     return [
-        BuildVariant(
-            name="loadbalanced",
-            display_name="loadbalanced",
-            tasks=[EvgTaskRef(name='.loadbalanced')]
-        ),
+        BuildVariant(name='loadbalanced', display_name='loadbalanced', tasks=[EvgTaskRef(name='.loadbalanced')]),
     ]
