@@ -29,6 +29,9 @@ script_dir="$(to_absolute "$(dirname "${BASH_SOURCE[0]}")")"
 declare mongoc_dir
 mongoc_dir="$(to_absolute "${script_dir}/../..")"
 
+. "${script_dir:?}/install-build-tools.sh"
+install_build_tools
+
 declare -a configure_flags
 
 configure_flags_append() {
@@ -73,73 +76,65 @@ fi
 configure_flags_append "-DCMAKE_BUILD_TYPE=${build_config:?}"
 configure_flags_append "-DENABLE_SSL=${SSL:-}"
 
-  # shellcheck source=.evergreen/scripts/find-cmake-version.sh
-. "${script_dir}/find-cmake-latest.sh"
-declare cmake_binary
-cmake_binary="$(find_cmake_latest)"
-"${cmake_binary:?}" --version
-
-export CMAKE_BUILD_PARALLEL_LEVEL
-CMAKE_BUILD_PARALLEL_LEVEL="$(nproc)"
-
 declare build_dir
 build_dir="cmake-build"
 
-if [[ "${CC}" =~ 'gcc' ]]; then
-  # MinGW has trouble compiling src/cpp-check.cpp without some assistance.
-  configure_flags_append "-DCMAKE_CXX_STANDARD=11"
-
-  env \
-    "${cmake_binary:?}" \
-    -S . \
-    -B "${build_dir:?}" \
-    -G "Ninja" \
-    "${configure_flags[@]}" \
-    "${extra_configure_flags[@]}"
-
-  env "${cmake_binary:?}" --build "${build_dir:?}"
-  env "${cmake_binary:?}" --build "${build_dir:?}" --target mongo_c_driver_tests
-  env "${cmake_binary:?}" --build "${build_dir:?}" --target mongo_c_driver_examples
-  exit 0
-fi
-
-# MSBuild needs additional assistance.
-# https://devblogs.microsoft.com/cppblog/improved-parallelism-in-msbuild/
-export UseMultiToolTask=1
-export EnforceProcessCountAcrossBuilds=1
-
-if [ "${COMPILE_LIBMONGOCRYPT}" = "ON" ]; then
-  echo "Installing libmongocrypt..."
-  # shellcheck source=.evergreen/scripts/compile-libmongocrypt.sh
-  "${script_dir}/compile-libmongocrypt.sh" "${cmake_binary}" "$(native-path "${mongoc_dir}")" "${install_dir}" &>output.txt || {
-    cat output.txt 1>&2
-    exit 1
-  }
-  echo "Installing libmongocrypt... done."
-
-  # Fail if the C driver is unable to find the installed libmongocrypt.
-  configure_flags_append "-DENABLE_CLIENT_SIDE_ENCRYPTION=ON"
-fi
-
 # Use ccache if able.
 . "${script_dir:?}/find-ccache.sh"
 find_ccache_and_export_vars "$(pwd)" || true
-if command -v "${CMAKE_C_COMPILER_LAUNCHER:-}" && [[ "${OSTYPE:?}" == cygwin ]]; then
-  configure_flags_append "-DCMAKE_POLICY_DEFAULT_CMP0141=NEW"
-  configure_flags_append "-DCMAKE_MSVC_DEBUG_INFORMATION_FORMAT=$<$<CONFIG:Debug,RelWithDebInfo>:Embedded>"
-fi
 
-"${cmake_binary:?}" -S . -B "${build_dir:?}" "${configure_flags[@]}" "${extra_configure_flags[@]}"
-"${cmake_binary:?}" --build "${build_dir:?}" --config "${build_config:?}"
-"${cmake_binary:?}" --install "${build_dir:?}" --config "${build_config:?}"
+if [[ "${CC}" =~ 'gcc' ]]; then
+  PATH="/cygdrive/c/ProgramData/chocolatey/lib/winlibs/tools/mingw64/bin:${PATH:-}" # mingw-w64 GCC
 
-# For use by test tasks, which directly use the binary directory contents.
-"${cmake_binary:?}" --build "${build_dir:?}" --config "${build_config:?}" --target mongo_c_driver_tests
+  export CMAKE_GENERATOR="Ninja"
 
-# Also validate examples.
-"${cmake_binary:?}" --build "${build_dir:?}" --config "${build_config:?}" --target mongo_c_driver_examples
+  # MinGW has trouble compiling src/cpp-check.cpp without some assistance.
+  configure_flags_append "-DCMAKE_CXX_STANDARD=11"
 
-if [[ "$EXTRA_CONFIGURE_FLAGS" != *"ENABLE_MONGOC=OFF"* ]]; then
-  # Check public headers for extra warnings.
-  "${cmake_binary:?}" --build "${build_dir:?}" --config "${build_config:?}" --target public-header-warnings
+  # mingw-w64 doesn't like lld (hangs indefinitely?).
+  configure_flags_append "-DMONGO_USE_LLD=OFF"
+
+  cmake "${configure_flags[@]}" "${extra_configure_flags[@]}" -B "${build_dir:?}"
+
+  cmake --build "${build_dir:?}" --target all mongo_c_driver_tests mongo_c_driver_examples
+else
+  # MSBuild task-based parallelism (VS 2019 16.3 and newer).
+  export UseMultiToolTask=true
+  export EnforceProcessCountAcrossBuilds=true
+  # MSBuild inter-project parallelism via CMake (3.26 and newer).
+  export CMAKE_BUILD_PARALLEL_LEVEL
+  CMAKE_BUILD_PARALLEL_LEVEL="$(nproc)" # /maxcpucount
+
+  if [ "${COMPILE_LIBMONGOCRYPT}" = "ON" ]; then
+    echo "Installing libmongocrypt..."
+    # shellcheck source=.evergreen/scripts/compile-libmongocrypt.sh
+    "${script_dir}/compile-libmongocrypt.sh" "$(command -v cmake)" "$(native-path "${mongoc_dir}")" "${install_dir}" &>output.txt || {
+      cat output.txt 1>&2
+      exit 1
+    }
+    echo "Installing libmongocrypt... done."
+
+    # Fail if the C driver is unable to find the installed libmongocrypt.
+    configure_flags_append "-DENABLE_CLIENT_SIDE_ENCRYPTION=ON"
+  fi
+
+  if command -v "${CMAKE_C_COMPILER_LAUNCHER:-}" && [[ "${OSTYPE:?}" == cygwin ]]; then
+    configure_flags_append "-DCMAKE_POLICY_DEFAULT_CMP0141=NEW"
+    configure_flags_append "-DCMAKE_MSVC_DEBUG_INFORMATION_FORMAT=$<$<CONFIG:Debug,RelWithDebInfo>:Embedded>"
+  fi
+
+  cmake -S . -B "${build_dir:?}" "${configure_flags[@]}" "${extra_configure_flags[@]}"
+  cmake --build "${build_dir:?}" --config "${build_config:?}"
+  cmake --install "${build_dir:?}" --config "${build_config:?}"
+
+  # For use by test tasks, which directly use the binary directory contents.
+  cmake --build "${build_dir:?}" --config "${build_config:?}" --target mongo_c_driver_tests
+
+  # Also validate examples.
+  cmake --build "${build_dir:?}" --config "${build_config:?}" --target mongo_c_driver_examples
+
+  if [[ "$EXTRA_CONFIGURE_FLAGS" != *"ENABLE_MONGOC=OFF"* ]]; then
+    # Check public headers for extra warnings.
+    cmake --build "${build_dir:?}" --config "${build_config:?}" --target public-header-warnings
+  fi
 fi
