@@ -19,12 +19,15 @@
 #ifndef MONGOC_CLIENT_PRIVATE_H
 #define MONGOC_CLIENT_PRIVATE_H
 
+#include <mongoc/mongoc-client.h> // IWYU pragma: export
+
+//
+
 #include <mongoc/mongoc-apm-private.h>
 #include <mongoc/mongoc-buffer-private.h>
 #include <mongoc/mongoc-cluster-private.h>
 #include <mongoc/mongoc-rpc-private.h>
 
-#include <mongoc/mongoc-client.h>
 #include <mongoc/mongoc-config.h>
 #include <mongoc/mongoc-host-list.h>
 #include <mongoc/mongoc-opcode.h>
@@ -131,7 +134,7 @@ typedef enum {
    MONGOC_CMD_RW = 3,
 } mongoc_command_mode_t;
 
-BSON_STATIC_ASSERT2 (mongoc_cmd_rw, MONGOC_CMD_RW == (MONGOC_CMD_READ | MONGOC_CMD_WRITE));
+BSON_STATIC_ASSERT2(mongoc_cmd_rw, MONGOC_CMD_RW == (MONGOC_CMD_READ | MONGOC_CMD_WRITE));
 
 
 /* TODO (CDRIVER-4052): Move MONGOC_RR_DEFAULT_BUFFER_SIZE and
@@ -139,103 +142,103 @@ BSON_STATIC_ASSERT2 (mongoc_cmd_rw, MONGOC_CMD_RW == (MONGOC_CMD_READ | MONGOC_C
  * There is no reason these should be in mongoc-client. */
 #define MONGOC_RR_DEFAULT_BUFFER_SIZE 1024
 bool
-_mongoc_client_get_rr (const char *hostname,
-                       mongoc_rr_type_t rr_type,
-                       mongoc_rr_data_t *rr_data,
-                       size_t initial_buffer_size,
-                       bool prefer_tcp,
-                       bson_error_t *error);
+_mongoc_client_get_rr(const char *hostname,
+                      mongoc_rr_type_t rr_type,
+                      mongoc_rr_data_t *rr_data,
+                      size_t initial_buffer_size,
+                      bool prefer_tcp,
+                      bson_error_t *error);
 
 mongoc_client_t *
-_mongoc_client_new_from_topology (mongoc_topology_t *topology);
+_mongoc_client_new_from_topology(mongoc_topology_t *topology);
 
 mongoc_stream_t *
-mongoc_client_default_stream_initiator (const mongoc_uri_t *uri,
-                                        const mongoc_host_list_t *host,
-                                        void *user_data,
-                                        bson_error_t *error);
+mongoc_client_default_stream_initiator(const mongoc_uri_t *uri,
+                                       const mongoc_host_list_t *host,
+                                       void *user_data,
+                                       bson_error_t *error);
 
 mongoc_stream_t *
-_mongoc_client_create_stream (mongoc_client_t *client, const mongoc_host_list_t *host, bson_error_t *error);
+_mongoc_client_create_stream(mongoc_client_t *client, const mongoc_host_list_t *host, bson_error_t *error);
 
 bool
-_mongoc_client_recv (mongoc_client_t *client,
-                     mcd_rpc_message *rpc,
-                     mongoc_buffer_t *buffer,
-                     mongoc_server_stream_t *server_stream,
-                     bson_error_t *error);
+_mongoc_client_recv(mongoc_client_t *client,
+                    mcd_rpc_message *rpc,
+                    mongoc_buffer_t *buffer,
+                    mongoc_server_stream_t *server_stream,
+                    bson_error_t *error);
 
 void
-_mongoc_client_kill_cursor (mongoc_client_t *client,
-                            uint32_t server_id,
-                            int64_t cursor_id,
-                            const char *db,
-                            const char *collection,
-                            mongoc_client_session_t *cs);
+_mongoc_client_kill_cursor(mongoc_client_t *client,
+                           uint32_t server_id,
+                           int64_t cursor_id,
+                           const char *db,
+                           const char *collection,
+                           mongoc_client_session_t *cs);
 bool
-_mongoc_client_command_with_opts (mongoc_client_t *client,
-                                  const char *db_name,
-                                  const bson_t *command,
-                                  mongoc_command_mode_t mode,
-                                  const bson_t *opts,
-                                  mongoc_query_flags_t flags,
-                                  const mongoc_read_prefs_t *user_prefs,
-                                  const mongoc_read_prefs_t *default_prefs,
-                                  mongoc_read_concern_t *default_rc,
-                                  mongoc_write_concern_t *default_wc,
-                                  bson_t *reply,
-                                  bson_error_t *error);
+_mongoc_client_command_with_opts(mongoc_client_t *client,
+                                 const char *db_name,
+                                 const bson_t *command,
+                                 mongoc_command_mode_t mode,
+                                 const bson_t *opts,
+                                 mongoc_query_flags_t flags,
+                                 const mongoc_read_prefs_t *user_prefs,
+                                 const mongoc_read_prefs_t *default_prefs,
+                                 mongoc_read_concern_t *default_rc,
+                                 mongoc_write_concern_t *default_wc,
+                                 bson_t *reply,
+                                 bson_error_t *error);
 
 mongoc_server_session_t *
-_mongoc_client_pop_server_session (mongoc_client_t *client,
-                                   const mongoc_ss_log_context_t *log_context,
-                                   bson_error_t *error);
+_mongoc_client_pop_server_session(mongoc_client_t *client,
+                                  const mongoc_ss_log_context_t *log_context,
+                                  bson_error_t *error);
 
 bool
-_mongoc_client_lookup_session (const mongoc_client_t *client,
-                               uint32_t client_session_id,
-                               mongoc_client_session_t **cs,
-                               bson_error_t *error);
+_mongoc_client_lookup_session(const mongoc_client_t *client,
+                              uint32_t client_session_id,
+                              mongoc_client_session_t **cs,
+                              bson_error_t *error);
 
 void
-_mongoc_client_unregister_session (mongoc_client_t *client, mongoc_client_session_t *session);
+_mongoc_client_unregister_session(mongoc_client_t *client, mongoc_client_session_t *session);
 
 void
-_mongoc_client_push_server_session (mongoc_client_t *client, mongoc_server_session_t *server_session);
+_mongoc_client_push_server_session(mongoc_client_t *client, mongoc_server_session_t *server_session);
 void
-_mongoc_client_end_sessions (mongoc_client_t *client);
+_mongoc_client_end_sessions(mongoc_client_t *client);
 
 mongoc_stream_t *
-mongoc_client_connect_tcp (int32_t connecttimeoutms, const mongoc_host_list_t *host, bson_error_t *error);
+mongoc_client_connect_tcp(int32_t connecttimeoutms, const mongoc_host_list_t *host, bson_error_t *error);
 
 mongoc_stream_t *
-mongoc_client_connect (bool use_ssl,
-                       void *ssl_opts_void,
-                       const mongoc_uri_t *uri,
-                       const mongoc_host_list_t *host,
-                       void *openssl_ctx_void,
-                       mongoc_shared_ptr secure_channel_cred_ptr,
-                       bson_error_t *error);
+mongoc_client_connect(bool use_ssl,
+                      void *ssl_opts_void,
+                      const mongoc_uri_t *uri,
+                      const mongoc_host_list_t *host,
+                      void *openssl_ctx_void,
+                      mongoc_shared_ptr secure_channel_cred_ptr,
+                      bson_error_t *error);
 
 
 /* Returns true if a versioned server API has been selected, otherwise returns
  * false. */
 bool
-mongoc_client_uses_server_api (const mongoc_client_t *client);
+mongoc_client_uses_server_api(const mongoc_client_t *client);
 
 
 /* Returns true if load balancing mode has been selected, otherwise returns
  * false. */
 bool
-mongoc_client_uses_loadbalanced (const mongoc_client_t *client);
+mongoc_client_uses_loadbalanced(const mongoc_client_t *client);
 
 void
-_mongoc_client_set_ssl_opts_for_single_or_pooled (mongoc_client_t *client, const mongoc_ssl_opt_t *opts);
+_mongoc_client_set_ssl_opts_for_single_or_pooled(mongoc_client_t *client, const mongoc_ssl_opt_t *opts);
 
 void
-_mongoc_client_set_stream_initiator_single_or_pooled (mongoc_client_t *client,
-                                                      mongoc_stream_initiator_t initiator,
-                                                      void *user_data);
+_mongoc_client_set_stream_initiator_single_or_pooled(mongoc_client_t *client,
+                                                     mongoc_stream_initiator_t initiator,
+                                                     void *user_data);
 
 BSON_END_DECLS
 
