@@ -20,14 +20,17 @@
 #define MONGOC_STREAM_TLS_SECURE_CHANNEL_H
 
 #ifdef MONGOC_ENABLE_SSL_SECURE_CHANNEL
-#include <bson/bson.h>
 
 #include <mongoc/mongoc-macros.h>
+#include <mongoc/mongoc-ssl.h>
+#include <mongoc/mongoc-stream.h>
+
+#include <bson/bson.h>
 
 BSON_BEGIN_DECLS
 
-MONGOC_EXPORT (mongoc_stream_t *)
-mongoc_stream_tls_secure_channel_new (mongoc_stream_t *base_stream, const char *host, mongoc_ssl_opt_t *opt, int client)
+MONGOC_EXPORT(mongoc_stream_t *)
+mongoc_stream_tls_secure_channel_new(mongoc_stream_t *base_stream, const char *host, mongoc_ssl_opt_t *opt, int client)
    BSON_GNUC_WARN_UNUSED_RESULT;
 
 BSON_END_DECLS
